import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import { getFileIcon, bytesToSize } from '@ciscospark/react-component-utils';
import { Icon, Button } from '@momentum-ui/react';

function styleInject(css, ref) {
  if (ref === void 0) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') {
    return;
  }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".react-component-activity-share-file__shareItem__LnNoYXJl {\n  position: relative;\n  display: flex;\n  height: 60px;\n  font-family: CiscoSans, 'Helvetica Neue', Arial, sans-serif;\n  color: #6a6b6c;\n  background-color: #ebebec;\n  border: 1px solid #ebebec;\n  border-radius: 4px;\n}\n\n.react-component-activity-share-file__fileIcon__LnNoYXJl {\n  display: flex;\n  flex: 0 0 auto;\n  align-items: center;\n  justify-content: center;\n  width: 60px;\n  height: 60px;\n}\n\n.react-component-activity-share-file__meta__LnNoYXJl {\n  display: flex;\n  flex: 1 1 auto;\n  align-items: center;\n  justify-content: center;\n  max-width: 200px;\n}\n\n.react-component-activity-share-file__fileInfo__LnNoYXJl {\n  font-size: 12px;\n  flex: 1 1 auto;\n}\n\n.react-component-activity-share-file__fileName__LnNoYXJl {\n  overflow: hidden;\n  text-overflow: ellipsis;\n  white-space: nowrap;\n}\n\n.react-component-activity-share-file__fileProps__LnNoYXJl {\n  color: #aeaeaf;\n}\n\n.react-component-activity-share-file__shareActions__LnNoYXJl {\n  display: flex;\n  flex: 0 0 auto;\n  width: 60px;\n}\n\n.react-component-activity-share-file__shareActionItem__LnNoYXJl {\n  margin: auto;\n  height: 32px;\n  width: 32px;\n}\n\n.react-component-activity-share-file__fileType__LnNoYXJl {\n  margin-left: 5px;\n}\n";
var styles = { "shareItem": "react-component-activity-share-file__shareItem__LnNoYXJl", "fileIcon": "react-component-activity-share-file__fileIcon__LnNoYXJl", "meta": "react-component-activity-share-file__meta__LnNoYXJl", "fileInfo": "react-component-activity-share-file__fileInfo__LnNoYXJl", "fileName": "react-component-activity-share-file__fileName__LnNoYXJl", "fileProps": "react-component-activity-share-file__fileProps__LnNoYXJl", "shareActions": "react-component-activity-share-file__shareActions__LnNoYXJl", "shareActionItem": "react-component-activity-share-file__shareActionItem__LnNoYXJl", "fileType": "react-component-activity-share-file__fileType__LnNoYXJl" };
styleInject(css);

var propTypes = {
  file: PropTypes.shape({
    displayName: PropTypes.string,
    fileSize: PropTypes.number,
    mimeType: PropTypes.string,
    objectType: PropTypes.string
  }).isRequired,
  isPending: PropTypes.bool,
  onDownloadClick: PropTypes.func.isRequired
};

var defaultProps = {
  isPending: false
};

function ActivityShareFile(props) {
  var file = props.file,
      isPending = props.isPending,
      onDownloadClick = props.onDownloadClick;
  var displayName = file.displayName,
      fileSize = file.fileSize,
      mimeType = file.mimeType,
      objectType = file.objectType;


  function handleDownloadClick() {
    onDownloadClick(file);
  }

  return React.createElement(
    'div',
    { className: classNames('ciscospark-activity-share-item', styles.shareItem) },
    React.createElement(
      'div',
      { className: classNames('ciscospark-share-file-icon', styles.fileIcon) },
      React.createElement(Icon, { name: 'icon-' + getFileIcon(mimeType, 32) })
    ),
    React.createElement(
      'div',
      { className: classNames('ciscospark-share-meta', styles.meta) },
      React.createElement(
        'div',
        { className: classNames('ciscospark-share-file-info', styles.fileInfo) },
        React.createElement(
          'div',
          { className: classNames('ciscospark-share-name', styles.fileName) },
          displayName
        ),
        React.createElement(
          'div',
          { className: classNames('ciscospark-share-file-props', styles.fileProps) },
          React.createElement(
            'span',
            { className: classNames('ciscospark-share-file-size', styles.fileSize) },
            bytesToSize(fileSize)
          ),
          React.createElement(
            'span',
            { className: classNames('ciscospark-share-file-type', styles.fileType) },
            objectType
          )
        )
      )
    ),
    !isPending && React.createElement(
      'div',
      { className: classNames('ciscospark-share-item-actions', styles.shareActions) },
      React.createElement(
        'div',
        { className: classNames('ciscospark-share-action-item', styles.shareActionItem) },
        React.createElement(
          Button,
          {
            ariaLabel: 'Download',
            style: { backgroundColor: 'black' },
            circle: true,
            onClick: handleDownloadClick,
            size: 32
          },
          React.createElement(Icon, { name: 'icon-arrow-tail-down_12', color: 'white' })
        )
      )
    )
  );
}

ActivityShareFile.propTypes = propTypes;
ActivityShareFile.defaultProps = defaultProps;

export default ActivityShareFile;
//# sourceMappingURL=index.js.map
